@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -75,7 +75,7 @@ __all__ = ("CodeArtifactClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -93,7 +93,7 @@ class Exceptions:
 
 class CodeArtifactClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html)
     """
 
@@ -111,7 +111,7 @@ class CodeArtifactClient(BaseClient):
         """
         Adds an existing external connection to a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#associate_external_connection)
         """
 
@@ -119,7 +119,7 @@ class CodeArtifactClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#can_paginate)
         """
 
@@ -133,8 +133,8 @@ class CodeArtifactClient(BaseClient):
         package: str,
         domainOwner: str = None,
         namespace: str = None,
-        versions: List[str] = None,
-        versionRevisions: Dict[str, str] = None,
+        versions: Sequence[str] = None,
+        versionRevisions: Mapping[str, str] = None,
         allowOverwrite: bool = None,
         includeFromUpstream: bool = None
     ) -> CopyPackageVersionsResultTypeDef:
@@ -142,17 +142,17 @@ class CodeArtifactClient(BaseClient):
         Copies package versions from one repository to another repository in the same
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#copy_package_versions)
         """
 
     def create_domain(
-        self, *, domain: str, encryptionKey: str = None, tags: List["TagTypeDef"] = None
+        self, *, domain: str, encryptionKey: str = None, tags: Sequence["TagTypeDef"] = None
     ) -> CreateDomainResultTypeDef:
         """
         Creates a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_domain)
         """
 
@@ -163,13 +163,13 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         domainOwner: str = None,
         description: str = None,
-        upstreams: List["UpstreamRepositoryTypeDef"] = None,
-        tags: List["TagTypeDef"] = None
+        upstreams: Sequence["UpstreamRepositoryTypeDef"] = None,
+        tags: Sequence["TagTypeDef"] = None
     ) -> CreateRepositoryResultTypeDef:
         """
         Creates a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_repository)
         """
 
@@ -177,7 +177,7 @@ class CodeArtifactClient(BaseClient):
         """
         Deletes a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain)
         """
 
@@ -187,7 +187,7 @@ class CodeArtifactClient(BaseClient):
         """
         Deletes the resource policy set on a domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain_permissions_policy)
         """
 
@@ -198,7 +198,7 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         format: PackageFormatType,
         package: str,
-        versions: List[str],
+        versions: Sequence[str],
         domainOwner: str = None,
         namespace: str = None,
         expectedStatus: PackageVersionStatusType = None
@@ -206,7 +206,7 @@ class CodeArtifactClient(BaseClient):
         """
         Deletes one or more versions of a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_package_versions)
         """
 
@@ -216,7 +216,7 @@ class CodeArtifactClient(BaseClient):
         """
         Deletes a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository)
         """
 
@@ -226,7 +226,7 @@ class CodeArtifactClient(BaseClient):
         """
         Deletes the resource policy that is set on a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository_permissions_policy)
         """
 
@@ -238,7 +238,7 @@ class CodeArtifactClient(BaseClient):
         IReference/API_DomainDescription.html>`__ object that contains information about
         the requested domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_domain)
         """
 
@@ -258,7 +258,7 @@ class CodeArtifactClient(BaseClient):
         atest/APIReference/API_PackageVersionDescription.html>`__ object that contains
         information about the requested package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_package_version)
         """
 
@@ -269,7 +269,7 @@ class CodeArtifactClient(BaseClient):
         Returns a `RepositoryDescription` object that contains detailed information
         about the requested repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_repository)
         """
 
@@ -279,7 +279,7 @@ class CodeArtifactClient(BaseClient):
         """
         Removes an existing external connection from a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#disassociate_external_connection)
         """
 
@@ -290,31 +290,31 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         format: PackageFormatType,
         package: str,
-        versions: List[str],
+        versions: Sequence[str],
         domainOwner: str = None,
         namespace: str = None,
-        versionRevisions: Dict[str, str] = None,
+        versionRevisions: Mapping[str, str] = None,
         expectedStatus: PackageVersionStatusType = None
     ) -> DisposePackageVersionsResultTypeDef:
         """
         Deletes the assets in package versions and sets the package versions' status to
         `Disposed`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#dispose_package_versions)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#generate_presigned_url)
         """
 
@@ -325,7 +325,7 @@ class CodeArtifactClient(BaseClient):
         Generates a temporary authorization token for accessing repositories in the
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_authorization_token)
         """
 
@@ -335,7 +335,7 @@ class CodeArtifactClient(BaseClient):
         """
         Returns the resource policy attached to the specified domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_domain_permissions_policy)
         """
 
@@ -355,7 +355,7 @@ class CodeArtifactClient(BaseClient):
         """
         Returns an asset (or file) that is in a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_asset)
         """
 
@@ -373,7 +373,7 @@ class CodeArtifactClient(BaseClient):
         """
         Gets the readme file or descriptive text for a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_readme)
         """
 
@@ -383,7 +383,7 @@ class CodeArtifactClient(BaseClient):
         """
         Returns the endpoint of a repository for a specific package format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_endpoint)
         """
 
@@ -393,7 +393,7 @@ class CodeArtifactClient(BaseClient):
         """
         Returns the resource policy that is set on a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_permissions_policy)
         """
 
@@ -405,7 +405,7 @@ class CodeArtifactClient(BaseClient):
         t/APIReference/API_PackageVersionDescription.html>`__ objects for all domains
         owned by the AWS account that makes this call.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_domains)
         """
 
@@ -426,7 +426,7 @@ class CodeArtifactClient(BaseClient):
         Returns a list of `AssetSummary <https://docs.aws.amazon.com/codeartifact/latest
         /APIReference/API_AssetSummary.html>`__ objects for assets in a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_assets)
         """
 
@@ -445,7 +445,7 @@ class CodeArtifactClient(BaseClient):
         """
         Returns the direct dependencies for a package version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_dependencies)
         """
 
@@ -468,7 +468,7 @@ class CodeArtifactClient(BaseClient):
         ct/latest/APIReference/API_PackageVersionSummary.html>`__ objects for package
         versions in a repository that match the request parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_versions)
         """
 
@@ -489,7 +489,7 @@ class CodeArtifactClient(BaseClient):
         st/APIReference/API_PackageSummary.html>`__ objects for packages in a repository
         that match the request parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_packages)
         """
 
@@ -500,7 +500,7 @@ class CodeArtifactClient(BaseClient):
         Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
         atest/APIReference/API_RepositorySummary.html>`__ objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories)
         """
 
@@ -518,7 +518,7 @@ class CodeArtifactClient(BaseClient):
         Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
         atest/APIReference/API_RepositorySummary.html>`__ objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories_in_domain)
         """
 
@@ -527,7 +527,7 @@ class CodeArtifactClient(BaseClient):
         Gets information about AWS tags for a specified Amazon Resource Name (ARN) in
         AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_tags_for_resource)
         """
 
@@ -542,7 +542,7 @@ class CodeArtifactClient(BaseClient):
         """
         Sets a resource policy on a domain that specifies permissions to access it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_domain_permissions_policy)
         """
 
@@ -559,23 +559,23 @@ class CodeArtifactClient(BaseClient):
         Sets the resource policy on a repository that specifies permissions to access
         it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_repository_permissions_policy)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds or updates tags for a resource in AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from a resource in AWS CodeArtifact.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#untag_resource)
         """
 
@@ -586,17 +586,17 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         format: PackageFormatType,
         package: str,
-        versions: List[str],
+        versions: Sequence[str],
         targetStatus: PackageVersionStatusType,
         domainOwner: str = None,
         namespace: str = None,
-        versionRevisions: Dict[str, str] = None,
+        versionRevisions: Mapping[str, str] = None,
         expectedStatus: PackageVersionStatusType = None
     ) -> UpdatePackageVersionsStatusResultTypeDef:
         """
         Updates the status of one or more versions of a package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_package_versions_status)
         """
 
@@ -607,19 +607,19 @@ class CodeArtifactClient(BaseClient):
         repository: str,
         domainOwner: str = None,
         description: str = None,
-        upstreams: List["UpstreamRepositoryTypeDef"] = None
+        upstreams: Sequence["UpstreamRepositoryTypeDef"] = None
     ) -> UpdateRepositoryResultTypeDef:
         """
         Update the properties of a repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_repository)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listdomainspaginator)
         """
 
@@ -628,7 +628,7 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_package_version_assets"]
     ) -> ListPackageVersionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionassetspaginator)
         """
 
@@ -637,14 +637,14 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_package_versions"]
     ) -> ListPackageVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_packages"]) -> ListPackagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackagespaginator)
         """
 
@@ -653,7 +653,7 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_repositories"]
     ) -> ListRepositoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriespaginator)
         """
 
@@ -662,6 +662,6 @@ class CodeArtifactClient(BaseClient):
         self, operation_name: Literal["list_repositories_in_domain"]
     ) -> ListRepositoriesInDomainPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriesindomainpaginator)
         """
