@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from botocore.response import StreamingBody
 
@@ -190,8 +190,8 @@ _OptionalCopyPackageVersionsRequestRequestTypeDef = TypedDict(
     {
         "domainOwner": str,
         "namespace": str,
-        "versions": List[str],
-        "versionRevisions": Dict[str, str],
+        "versions": Sequence[str],
+        "versionRevisions": Mapping[str, str],
         "allowOverwrite": bool,
         "includeFromUpstream": bool,
     },
@@ -225,7 +225,7 @@ _OptionalCreateDomainRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDomainRequestRequestTypeDef",
     {
         "encryptionKey": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -257,8 +257,8 @@ _OptionalCreateRepositoryRequestRequestTypeDef = TypedDict(
     {
         "domainOwner": str,
         "description": str,
-        "upstreams": List["UpstreamRepositoryTypeDef"],
-        "tags": List["TagTypeDef"],
+        "upstreams": Sequence["UpstreamRepositoryTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -345,7 +345,7 @@ _RequiredDeletePackageVersionsRequestRequestTypeDef = TypedDict(
         "repository": str,
         "format": PackageFormatType,
         "package": str,
-        "versions": List[str],
+        "versions": Sequence[str],
     },
 )
 _OptionalDeletePackageVersionsRequestRequestTypeDef = TypedDict(
@@ -571,7 +571,7 @@ _RequiredDisposePackageVersionsRequestRequestTypeDef = TypedDict(
         "repository": str,
         "format": PackageFormatType,
         "package": str,
-        "versions": List[str],
+        "versions": Sequence[str],
     },
 )
 _OptionalDisposePackageVersionsRequestRequestTypeDef = TypedDict(
@@ -579,7 +579,7 @@ _OptionalDisposePackageVersionsRequestRequestTypeDef = TypedDict(
     {
         "domainOwner": str,
         "namespace": str,
-        "versionRevisions": Dict[str, str],
+        "versionRevisions": Mapping[str, str],
         "expectedStatus": PackageVersionStatusType,
     },
     total=False,
@@ -1314,7 +1314,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1330,7 +1330,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1341,7 +1341,7 @@ _RequiredUpdatePackageVersionsStatusRequestRequestTypeDef = TypedDict(
         "repository": str,
         "format": PackageFormatType,
         "package": str,
-        "versions": List[str],
+        "versions": Sequence[str],
         "targetStatus": PackageVersionStatusType,
     },
 )
@@ -1350,7 +1350,7 @@ _OptionalUpdatePackageVersionsStatusRequestRequestTypeDef = TypedDict(
     {
         "domainOwner": str,
         "namespace": str,
-        "versionRevisions": Dict[str, str],
+        "versionRevisions": Mapping[str, str],
         "expectedStatus": PackageVersionStatusType,
     },
     total=False,
@@ -1385,7 +1385,7 @@ _OptionalUpdateRepositoryRequestRequestTypeDef = TypedDict(
     {
         "domainOwner": str,
         "description": str,
-        "upstreams": List["UpstreamRepositoryTypeDef"],
+        "upstreams": Sequence["UpstreamRepositoryTypeDef"],
     },
     total=False,
 )
